Index: frame.c
===================================================================
--- frame.c	(revision 33812)
+++ frame.c	(working copy)
@@ -137,6 +137,11 @@
 	s->flags = flags;
 }
 
+int ast_smoother_test_flag(struct ast_smoother *s, int flag)
+{
+	return (s->flags & flag);
+}
+
 int __ast_smoother_feed(struct ast_smoother *s, struct ast_frame *f, int swap)
 {
 	if (f->frametype != AST_FRAME_VOICE) {
@@ -1000,7 +1005,22 @@
 	return x;
 }
 
+/*! \brief Set packet size for codec */
+int ast_codec_pref_setsize(struct ast_codec_pref *pref, int format, int framems)
+{
+	int x;
 
+	for (x = 0; x < sizeof(AST_FORMAT_LIST) / sizeof(AST_FORMAT_LIST[0]); x++) {
+		if(pref->order[x] == format) {
+			pref->psize[x] = framems;
+			break;
+		}
+	}
+
+	return x;
+}
+
+
 /*! \brief Pick a codec */
 int ast_codec_choose(struct ast_codec_pref *pref, int formats, int find_best)
 {
@@ -1029,10 +1049,20 @@
 {
 	char *parse;
 	char *this;
+	char *psize;
+	int framems;
 	int format;
 
 	parse = ast_strdupa(list);
 	while ((this = strsep(&parse, ","))) {
+		if ((psize=strrchr(this,':'))) {
+			psize='\0';
+			psize++;
+			framems=strtol(psize,NULL,10);
+			if (framems==LONG_MIN || framems==LONG_MAX) {
+				framems=0;
+			}
+		}
 		if (!(format = ast_getformatbyname(this))) {
 			ast_log(LOG_WARNING, "Cannot %s unknown format '%s'\n", allowing ? "allow" : "disallow", this);
 			continue;
@@ -1050,9 +1080,10 @@
 		 */
 		if (pref && (format & AST_FORMAT_AUDIO_MASK)) {
 			if (strcasecmp(this, "all")) {
-				if (allowing)
+				if (allowing) {
 					ast_codec_pref_append(pref, format);
-				else
+					ast_codec_pref_setsize(pref, format, framems);
+				} else
 					ast_codec_pref_remove(pref, format);
 			} else if (!allowing) {
 				memset(pref, 0, sizeof(*pref));
Index: include/asterisk/frame.h
===================================================================
--- include/asterisk/frame.h	(revision 33812)
+++ include/asterisk/frame.h	(working copy)
@@ -35,6 +35,7 @@
 
 struct ast_codec_pref {
 	char order[32];
+	char psize[32];
 };
 
 /*! \page Def_Frame AST Multimedia and signalling frames
@@ -270,6 +271,7 @@
 };
 
 #define AST_SMOOTHER_FLAG_G729		(1 << 0)
+#define AST_SMOOTHER_FLAG_BE		(1 << 1)
 
 /* Option identifiers and flags */
 #define AST_OPTION_FLAG_REQUEST		0
@@ -445,6 +447,7 @@
 void ast_smoother_reset(struct ast_smoother *s, int bytes);
 int __ast_smoother_feed(struct ast_smoother *s, struct ast_frame *f, int swap);
 struct ast_frame *ast_smoother_read(struct ast_smoother *s);
+extern int ast_smoother_test_flag(struct ast_smoother *s, int flag);
 #define ast_smoother_feed(s,f) __ast_smoother_feed(s, f, 0)
 #if __BYTE_ORDER == __LITTLE_ENDIAN
 #define ast_smoother_feed_be(s,f) __ast_smoother_feed(s, f, 1)
@@ -482,6 +485,10 @@
 */
 int ast_codec_pref_append(struct ast_codec_pref *pref, int format);
 
+/*! \brief Set packet size for codec
+*/
+int ast_codec_pref_setsize(struct ast_codec_pref *pref, int format, int framems);
+
 /*! \brief Select the best audio format according to preference list from supplied options. 
    If "find_best" is non-zero then if nothing is found, the "Best" format of 
    the format list is selected, otherwise 0 is returned. */
